@@ -1,7 +1,7 @@
 converged <- function(fit, step="init step", stop=FALSE){
   if (fit$convergence==1) {
     ret <- FALSE
-    if (stop) stop(paste("iteration limit 'maxit' have been reached", step, sep=" "))
+    if (stop) stop(paste("iteration limit 'maxit' have been reached in", step, sep=" "))
   }
   else if (fit$convergence==10) {
     ret <- FALSE
