@@ -5,12 +5,12 @@ ll_flexrsurv_alpha0alpha<-function(alpha0alpha, beta0, beta, gamma0,
                                    step, Nstep, 
                                  intTD=intTD_NC, intweightsfunc=intweights_CAV_SIM,
                                  nT0basis,
-                                 Spline_t0=MSplineBasis(knots=NULL,  degree=3,   keep.duplicates=TRUE), Intercept_t0=TRUE,
+                                 Spline_t0=BSplineBasis(knots=NULL,  degree=3,   keep.duplicates=TRUE), Intercept_t0=TRUE,
                                  ialpha0, nX0,
                                  nX, 
                                  ialpha,
                                  nTbasis,
-                                 Spline_t =MSplineBasis(knots=NULL,  degree=3,   keep.duplicates=TRUE),
+                                 Spline_t =BSplineBasis(knots=NULL,  degree=3,   keep.duplicates=TRUE),
                                  Intercept_t_NPH=rep(TRUE, nX), 
                                  debug=FALSE,  ...){
   # compute log likelihood of the relative survival model
@@ -97,7 +97,7 @@ YT0Gamma0 <- predictSpline(Spline_t0*tmpgamma0, Y[,1], intercept=Intercept_t0)
   }
 
   if(nX + nZ) {
-    NPHterm <- intTD(rateTD_gamma0alphabeta, Y[,1], fail=Y[,2],
+    NPHterm <- intTD(rateTD_gamma0alphabeta, intTo=Y[,1], intToStatus=Y[,2],
                      step, Nstep,
                      intweightsfunc=intweightsfunc, 
                      gamma0=gamma0, Zalphabeta=Zalphabeta, 
@@ -105,7 +105,7 @@ YT0Gamma0 <- predictSpline(Spline_t0*tmpgamma0, Y[,1], intercept=Intercept_t0)
                      Spline_t = Spline_t, Intercept_t=TRUE)
   }
   else {
-    NPHterm <- intTD(rateTD_gamma0, Y[,1], fail=Y[,2],
+    NPHterm <- intTD(rateTD_gamma0, intTo=Y[,1], intToStatus=Y[,2],
                      step=step, Nstep=Nstep,
                      intweightsfunc=intweightsfunc, 
                      gamma0=gamma0,
