@@ -5,11 +5,11 @@ ll_flexrsurv_beta0beta<-function(beta0beta, alpha, gamma0, alpha0,
                                  step, Nstep, 
                                intTD=intTD_NC, intweightsfunc=intweights_CAV_SIM,
                                nT0basis,
-                               Spline_t0=MSplineBasis(knots=NULL,  degree=3,   keep.duplicates=TRUE), Intercept_t0=TRUE, 
+                               Spline_t0=BSplineBasis(knots=NULL,  degree=3,   keep.duplicates=TRUE), Intercept_t0=TRUE, 
                                nX0,
                                ibeta0, nX, 
                                ibeta, nTbasis,
-                               Spline_t =MSplineBasis(knots=NULL,  degree=3,   keep.duplicates=TRUE),
+                               Spline_t =BSplineBasis(knots=NULL,  degree=3,   keep.duplicates=TRUE),
                                Intercept_t_NPH=FALSE,
                                debug=FALSE, ...){
   # compute log likelihood of the relative survival  model
@@ -95,7 +95,7 @@ YT0Gamma0 <- predictSpline(Spline_t0*tmpgamma0, Y[,1], intercept=Intercept_t0)
   
 
   if( nX+nZ ){
-    NPHterm <- intTD(rateTD_gamma0alphabeta, Y[,1], fail=Y[,2],
+    NPHterm <- intTD(rateTD_gamma0alphabeta, intTo=Y[,1], intToStatus=Y[,2],
                      step, Nstep,
                      intweightsfunc=intweightsfunc, 
                      gamma0=gamma0, Zalphabeta=Zalphabeta, 
@@ -103,7 +103,7 @@ YT0Gamma0 <- predictSpline(Spline_t0*tmpgamma0, Y[,1], intercept=Intercept_t0)
                      Spline_t = Spline_t, Intercept_t=TRUE)
   }
   else {
-    NPHterm <- intTD(rateTD_gamma0, Y[,1], fail=Y[,2],
+    NPHterm <- intTD(rateTD_gamma0, intTo=Y[,1], intToStatus=Y[,2],
                      step=step, Nstep=Nstep,
                      intweightsfunc=intweightsfunc, 
                      gamma0=gamma0,
